#' Posterior probability of treatment efficacy
#'
#' The function computes the posterior probability of a treatment effect \eqn{p(\theta_a > \theta_0 | Data)}
#' for the response rates \eqn{\theta_a, a > 0} of each experimental treatment.
#'
#' @param Outcome
#' A matrix with two rowns and one column of each treatment.
#' The 1st and 2nd column correspons to the number of observed and
#' observed positive outcome for each treatment.
#'
#' @examples
#' Outcome = rbind(N = 16:19,
#'                 Y = rbinom(4, 16:19, .5))
#' Posterior.with.control(Outcome=Outcome)
#'
#' @export
Posterior.with.control = function(Outcome){

  # get hyper-parameter
  #v         = expand.grid(seq(1, 9, 1.5), seq(1, 9, 1.5))
  #BB        = function(v) sum(lbeta(Outcome[2,]+v[1], Outcome[1,]-Outcome[2,]+v[2])) - ncol(Outcome)*sum(lbeta(v[1], v[2]))
  #ML        = apply(v, 1, BB)
  v         = c(1,1)#as.double(v[which.max(ML),])
  v.mat     = matrix(v,2,ncol(Outcome)) + rbind(Outcome[2,], Outcome[1,]-Outcome[2,])
  Grid      = seq(.05, .95, .05)

  Pr.0  = dbeta(x=Grid, shape1=v.mat[1,1], shape2=v.mat[2,1])
  Pr.0  = Pr.0 / sum(Pr.0)
  F.0   = cumsum( Pr.0 )
  F.0   = c(0, F.0[-length(F.0)])

  Pr.a  = t(apply(v.mat[,-1], 2, function(x){ p = dbeta(Grid, shape1=x[1], shape2=x[2]); return(p/sum(p)) }))

  return(as.double( t(Pr.a %*% F.0)))
}
