#' Z-statistics for Difference in Probabilities
#'
#' Compute for \code{A=ncol(Outcome)} arms the z-statistics,
#' i.e. standardised estimated treatment different between arm \eqn{a>1} and arm 1.
#'
#' @param Outcome
#' A matrix with two rowns and one column of each treatment.
#' The 1st and 2nd column correspons to the number of observed and
#' observed positive outcome for each treatment.
#'
#' @return A vector if z-values, one value for each experimental arm.
#'
#' @examples
#' Outcome  = rbind(N = 16:19,
#'                 Y = rbinom(4, 16:19, .5))
#'
#' Test.statistics(Outcome=Outcome)
#'
#' @keywords internal
#' @export
Test.statistics = function(Outcome)
{

  p.a =  Outcome[2,] / Outcome[1,]
  p.0 = (Outcome[2,-1]+Outcome[2,1])  / ( Outcome[1,-1] + Outcome[1,1] )

  z   = (p.a[-1]-p.a[1]) / sqrt( (p.0*(1-p.0))*( 1/Outcome[1,-1] + 1/Outcome[1,1]) )


  if(Outcome[1,1]==0){ return(rep(0, ncol(Outcome)-1))

  }else              { z[Outcome[1,-1]==0] = 0
                       z[is.infinite(z)]   = 0
                       z[is.na(z)]         = 0

                       return(z)                       }
}
