% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Apply.stopping.rules.R
\name{Apply.stopping.rules}
\alias{Apply.stopping.rules}
\title{Early Futility Stopping Rule}
\usage{
Apply.stopping.rules(i, Active, PrPTE, stop.par = c(f = 0, gf = 1), Accrual,
  n.a.max)
}
\arguments{
\item{i}{Number of patients randomized.}

\item{Active}{A 2xA matrix which contains the activity status for each arm (1. column control).
The element \code{Active[1,a]} equals 1,0,2
if arm a is active, was dropped for futility or graduated for efficacy.}

\item{PrPTE}{\code{PrPTE} is a vector which contains, for each experimental arm,
the posterior probability of treatment efficacy
\code{PrPTE[a]} \eqn{=p(\theta_a > \theta_0 | Data)}
The vector can be generated with \code{\link{Posterior.with.control}}.}

\item{stop.par}{Vector of two elements, \code{stop.par[1]}
the treshold probability after the  maximum patient accrual is reached and
a non-negative shape parameter \code{stop.par[2]}.}

\item{Accrual}{Current number of observed outcomes for each arm.}

\item{n.a.max}{Maximum sample size for each experimental arm.}
}
\description{
Drop experimental arms for futility if the posterior probability of efficacy becomes small.
}
\details{
The function drops experimental arms for futility if the  posterior probabilities of treatment efficacy
 dropps belows a treshold. The futility treshold depends on the number of observed outcomes \eqn{N_a} for each arm a,

 \code{PrPTE[a]} \eqn{=p(\theta_a > \theta_0 | Data) \le f * (N_a/n'_E)^g}
}
\examples{
# current outcome data
Outcome  = rbind(N=c(34, 23, 45, 34),
                 X=c(15, 12, 30, 15))

# posterior probability of treatment efficacy
PrPTE    = Posterior.with.control(Outcome=Outcome)

# number of patients randomized
Accrual  = c(44, 33, 55, 44)
n.a.max  = rep(55, 3)

# activity status and futility stopping parameter
stop.par = c(f=.3,gf=1)
Active   = rbind(status        = rep(1, 4),
                 dropped.after = rep(0,4))

# apply futility stopping rules
Apply.stopping.rules(i=147, Active, PrPTE, stop.par, Accrual, n.a.max)

}

