% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BayesianAdaptiveDesign.R
\name{Randomize.BAR.add}
\alias{Randomize.BAR.add}
\title{Generate random numbers for a Bayesian Adaptive treatment assignment}
\usage{
Randomize.BAR.add(Accrual, k.c, batch, m.k, n.k, PrPTE, rand, q.vec, n.a.max,
  Active = rep(1, length(PrPTE)), nr.a = 1)
}
\arguments{
\item{Accrual}{The number of patients randomized to each treatment arm.}

\item{k.c}{Current number of groups of added arms (initial group counts too).}

\item{batch}{Group membership for each treatment arm (for control put 1).}

\item{m.k}{Mean parameter of the Gompertz function for each treatment group,}

\item{n.k}{Extension of the overall sample size of the trial after each group of added arms.}

\item{PrPTE}{\code{PrPTE} is a vector which contains, for each experimental arm,
the posterior probability of treatment efficacy
\code{PrPTE[a]} \eqn{=p(\theta_a > \theta_0 | Data)}.
The vector can be generated with \code{\link{Posterior.with.control}}.}

\item{rand}{A vector three tuning parameter for adaptive randomization \code{rand =c(a,b,c)}.
The first and second element correspond to the maximum
and the shap parameter of the power function \eqn{h(x) = a * (x/n)^b}
The last parameter controls the randomization to the control.}

\item{q.vec}{The 3 common parameter \eqn{ (r_0, r_1,r_3) } of the Gompertz function
\eqn{q_k(x) = r_0 + r_1 \exp(-\exp( -r_2 [x-m_k] ))}.}

\item{n.a.max}{Vector of maximum sample sizes for each experimental arm.}

\item{Active}{Activity status for each experimental arm at the i-th arrival,
i.e. \code{Active[k]=1} or \code{TRUE} if  k-th arm is active.}

\item{nr.a}{How many random numbers should be generated}
}
\value{
Returns a set of \code{nr.a} treatment assignment numbers.
}
\description{
Generate a random vector of \code{nr.a} treatment assignment variables for the Bayesian adaptive design.
}
\details{
The function generates integers between 1 and A, where A is the number of arms in the trial.
Each random integer \eqn{ C_i= \{1,\ldots, A\}} denotes the assignment of patient i to
the control (\eqn{C_i=1}) or experimental arm  (\eqn{ C_i= \{2,\ldots, A\}}).
The random numbers are drawn under a Bayesian outcome-adaptive assignment model.
}
\examples{
# current outcome data
Outcome      = rbind( N=c(34, 32, 25, 0),
                      X=c(20, 19, 22, 0))

# activity status and futility stopping parameter
Accrual      = c(44, 42, 35, 5)

PrPTE        = Posterior.with.control(Outcome)

# add 3th experimental arm after 101 patients
added.at     = c(0,0,0, 102)
batch        = c(1,1,1, 2)
rand         = c(H=2, gamma=1, b=.1)
q.vec        = c(r1=1, r2=2, r3=.1)

# change platou of the Gompertz function after 60 and 30 Accrual patients
m.k          = c(60, 30)

# extend sample size by 63 patients
n.k          = c(2*63, 63)
n.a.max      = rep(63, 3)

Randomize.BAR.add(Accrual, k.c=2, batch, m.k, n.k, PrPTE, rand, q.vec, n.a.max, nr.a=5)
}

