% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BalancedDesigns.R
\name{Randomize.BR.add}
\alias{Randomize.BR.add}
\title{Generate Random Numbers Using Balanced Randomization}
\usage{
Randomize.BR.add(q.vec, Accrual, N.target, Active = rep(1, length(Accrual)),
  nr.a = 1)
}
\arguments{
\item{q.vec}{Vector of randomization weights, one weight for each arm.}

\item{Accrual}{The number of patients already enrolled to each arm.}

\item{N.target}{Vector of the targeted sample sizes for each arm.}

\item{Active}{Activity status, one if active and zero else,
for each arm at the i-th arrival.}

\item{nr.a}{How many random numbers should be generated}
}
\value{
Returns a set of \code{nr.a} random treatment assignment numbers.
}
\description{
The function generates random numbers for treatment assignment
using balanced randomization.
}
\details{
The function generates random numbers \eqn{C_i} with probability proportional to
\deqn{p(C_i=a) \propto q_a I(N_a < n_{T,a},}
where \eqn{q_a, N_a, n_{T,a}} are
the randomization weight,
number of patients enrolled and maximal enrollment to arm a.
}
\examples{
## 5 arms
Accrual  = c(51, 49, 47, 10, 10)   # current accrual
N.target = rep(50, 5)              # maximum accrual
q.vec    = c(2,1,1,1.5,1.5)        # randomization weights
Active   = c(1,0,1,1,0)            # arms 2 and 5 are inactive

Randomize.BR.add(q.vec, Accrual, N.target, nr.a=5)

}

