% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DoublyAdaptiveBiasedCoinDesign.R
\name{Randomize.DBCD.add}
\alias{Randomize.DBCD.add}
\title{Random Numbers for Doubly Adaptive Biased Coin Designs}
\usage{
Randomize.DBCD.add(Accrual, Outcome, k.c, batch, h.k, n.k, rand, n.a.max,
  Active = rep(1, length(Accrual)))
}
\arguments{
\item{Accrual}{The number of patients Accrual to each treatment arm.}

\item{Outcome}{A matrix, where the 1./2. row contains the observed/positive outcomes for each active arm.}

\item{k.c}{Current number of added groups (initial groups counts too)}

\item{batch}{Group membership for each treatment arm (for control put 1)}

\item{h.k}{Initial level of corrections for each batch}

\item{n.k}{Extension of the overall sample size for goup of added arms}

\item{rand}{A vector of tuning parameter.}

\item{n.a.max}{Vector of maximum sample sizes for each experimental arm.}

\item{Active}{Activity status for each arm at the i-th arrival.}
}
\description{
Generate a vector of \code{nr.a} intergers of treatment assignments
under doubly adaptive biased coin designs.
}
\details{
The function generates integers between from  \eqn{ \{1,\ldots, A\}}, where \code{A=length(PrPTE)-1}.
Each random integer \eqn{ C_i= \{1,\ldots, A\}} represents the treatment assignment to the control,
if  \eqn{C_i=1} or experimental arm  \eqn{ C_i= \{2,\ldots, A\}}.

The random numbers are drawn under a doubly adaptive biased coin designs assignment model.
}
\examples{
# current outcome data
Outcome      = rbind( N=c(34, 32, 25, 0),
                      X=c(20, 19, 22, 0))

# activity status and futility stopping parameter
Accrual      = c(44, 42, 35, 5)

PrPTE        = Posterior.with.control(Outcome)

# add 3th experimental arm after 101 patients
added.at     = c(0,0,0, 102)
batch        = c(1,1,1, 2)

rand         = c(H=3, gamma=1)
h.k          = c(h1=1, h2=2)

# extend sample size by 63 patients
n.k          = c(2*63, 63)
n.a.max      = rep(63, 3)

Randomize.DBCD.add(Accrual, Outcome, k.c=2, batch, h.k, n.k, rand, n.a.max)
}

