% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BalancedDesigns.R
\name{Simulate.BR.add.trial}
\alias{Simulate.BR.add.trial}
\title{Simulate a Trial using Balanced Randomization}
\usage{
Simulate.BR.add.trial(Potential.Outcome, added.at = rep(0,
  ncol(Potential.Outcome)), Outcome.delay = 0, N.target, q.vec,
  stop.par = c(f = 0, gf = 1), use.concurrent = FALSE,
  do.futi.stop = FALSE)
}
\arguments{
\item{Potential.Outcome}{A matrix with  potential outcome data
be generated with \code{\link{Generat.Outcome}}.}

\item{added.at}{A vector of adding times for each arm.
For all initial arms use \code{0}.}

\item{Outcome.delay}{Expected time between enrolments and avalability of the outcome.
(If the endpoint is response after 6 month of treatment then \code{Outcome.delay=6}).}

\item{N.target}{Vector of the targeted sample size for each arm.
No more than \code{N.target[k]} patients will be enrolled to arm k.}

\item{q.vec}{Vector of randomization weights, one weight for each arm.}

\item{stop.par}{Vector of stopping parameters with default c(f=0, g=1).}

\item{use.concurrent}{If TRUE only  concurrent control data are used for treatment comparision.}

\item{do.futi.stop}{If \code{TRUE} do sequantial futility analysis.}
}
\value{
The function returns a list \code{list(Potential.Outcome, Outcome=Outcome, Active=Active)} of three elements.

\code{Potential.Outcome} is identical to the impute matrix \code{Potential.Outcome}
except that the 2nd  column now contains treatment assignment variables, i.e.
\code{Potential.Outcome[10,2]} equals one if the 10th patients was Accrual to the control.
\code{Potential.Outcome[10,2]} equals 2 if the 10th patients was Accrual to the arm 1.

\code{Outcome} is an array of outcome data,
where \code{Outcome[,,k]} corresponds to the outcome data in the kth group of added arms.

\code{Active} corresponds to the activity status of each arm.
}
\description{
Generate a multi-arm trial using a balanced design,
with early stopping for futility,
and the possibility to  add arms to the trial.
}
\examples{
# generate outcome data
X = Generat.Outcome(N=5*63, p.vec=rep(.3, 5), A.rate=6)

#generate trial
Simulate.BR.add.trial(
   Potential.Outcome= X,

   # add two arms after the enrolment of 74 patients
   added.at         = c(rep(0, 3),75, 75),

   # at most 50 patients for each arm
   N.target         = rep(50, 5),

   # equal randomization weithgs
   q.vec            = rep(1,5),
   stop.par         = c(f=0.3, gf=1))

}

