% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DoublyAdaptiveBiasedCoinDesign.R
\name{Simulate.DBCD.add.trial}
\alias{Simulate.DBCD.add.trial}
\title{Simulate a Trial under Doubly Adaptive Biased Coin Designs with Futility Stopping}
\usage{
Simulate.DBCD.add.trial(Potential.Outcome, added.at = rep(0,
  ncol(Potential.Outcome)), Outcome.delay, n.a.max, rand, h.k, n.k,
  stop.par = c(f = 0, gf = 1), do.futi.stop = TRUE)
}
\arguments{
\item{Potential.Outcome}{A matrix with one potential outcome data for each arm.
The data can be generated with \code{\link{Generat.Outcome}}.}

\item{added.at}{A vector of adding times for each arm.
For all initial arms use \code{0}.}

\item{Outcome.delay}{Expected time between enrolments and avalability of the outcome.
I.e. if the endpoint is respons to treatment at 6 month, \code{Outcome.delay=6}.}

\item{n.a.max}{Vector of maximum sample sizes for each experimental arm.}

\item{rand}{A vector \code{rand =c(H, gamma)} of randomization three tuning parameter.
The first and second element correspond to the maximum
and the shap parameter of the power function \eqn{h(x) = H * (x/n)^gamma}
The last parameter controls the randomization to the control.#'}

\item{h.k}{Initial level of corrections for each group of added arms.}

\item{n.k}{Extension of the overall sample size for each group of added arms.}

\item{stop.par}{Vector of stopping parameters with default c(f=0, gf=1).}

\item{do.futi.stop}{If \code{TRUE} do sequantial futility analysis.}
}
\value{
The function returns a list \code{list(Potential.Outcome, Outcome=Outcome, Active=Active)} of three elements.

\code{Potential.Outcome} is identical to the impute matrix \code{Potential.Outcome}
except that the 2nd  column now contains treatment assignment variables, i.e.
\code{Potential.Outcome[10,2]} equals one if the 10th patients was Accrual to the control.
\code{Potential.Outcome[10,2]} equals 2 if the 10th patients was Accrual to the arm 1.

\code{Outcome} is an array of outcome data,
where \code{Outcome[,,k]} corresponds to the outcome data in the kth group of added arms.

\code{Active} corresponds to the activity status of each arm.
}
\description{
Generate a multi-arm trial under a Doubly Adaptive Biased Coin designs
with early stopping for futility and the possibility of adding one or multiple arms to the trial.
}
\examples{
# generate outcome data
X = Generat.Outcome(N=5*63, p.vec=rep(.3, 5), A.rate=6)

# generate trial
Simulate.DBCD.add.trial(
  Potential.Outcome = X,

  # add one arm after 79 & another after 99 patients
  added.at          = c(0,0,0, 80,100),
  Outcome.delay     = 20,

  # randomize at most 75 patients to each arm
  n.a.max           = rep(75, 4),

  # randomization parameter
  rand              = c(a=1, b=1, c=.1),
  h.k               = c(0, 1, 1),
  n.k               = c(2*63, 63, 63),

  # futility stopping parameter
  stop.par          = c(f=.3, gf=1),
  do.futi.stop      = TRUE )

}

